package sun.security.x509;

import java.security.cert.CertificateException;
import java.util.Enumeration;
import java.io.OutputStream;
import sun.security.util.DerInputStream;
import java.io.IOException;
import sun.security.util.DerValue;
import sun.security.util.DerOutputStream;

public class PolicyConstraintsExtension extends Extension implements CertAttrSet<String>
{
    public static final String IDENT = "x509.info.extensions.PolicyConstraints";
    public static final String NAME = "PolicyConstraints";
    public static final String REQUIRE = "require";
    public static final String INHIBIT = "inhibit";
    private static final byte TAG_REQUIRE = 0;
    private static final byte TAG_INHIBIT = 1;
    private int require;
    private int inhibit;
    
    private void encodeThis() throws IOException {
        if (this.require == -1 && this.inhibit == -1) {
            this.extensionValue = null;
            return;
        }
        DerOutputStream derOutputStream = new DerOutputStream();
        DerOutputStream derOutputStream2 = new DerOutputStream();
        if (this.require != -1) {
            DerOutputStream derOutputStream3 = new DerOutputStream();
            derOutputStream3.putInteger(this.require);
            derOutputStream.writeImplicit(DerValue.createTag((byte)(-128), false, (byte)0), derOutputStream3);
        }
        if (this.inhibit != -1) {
            DerOutputStream o = new DerOutputStream();
            o.putInteger(this.inhibit);
            derOutputStream.writeImplicit(DerValue.createTag((byte)(-128), false, (byte)1), o);
        }
        derOutputStream2.write((byte)48, derOutputStream);
        this.extensionValue = derOutputStream2.toByteArray();
        return;
    }
    
    public PolicyConstraintsExtension(int n, int n2) throws IOException {
        this(Boolean.FALSE, n, n2);
    }
    
    public PolicyConstraintsExtension(Boolean b, int require, int inhibit) throws IOException {
        this.require = -1;
        this.inhibit = -1;
        this.require = require;
        this.inhibit = inhibit;
        this.extensionId = PKIXExtensions.PolicyConstraints_Id;
        this.critical = (boolean)b;
        this.encodeThis();
    }
    
    public PolicyConstraintsExtension(Boolean b, Object o) throws IOException {
        this.require = -1;
        this.inhibit = -1;
        this.extensionId = PKIXExtensions.PolicyConstraints_Id;
        this.critical = (boolean)b;
        this.extensionValue = (byte[])(byte[])o;
        DerValue derValue = new DerValue(this.extensionValue);
        if (derValue.tag != 48) {
            throw new IOException("Sequence tag missing for PolicyConstraint.");
        }
        DerInputStream data = derValue.data;
        while (data != null && data.available() != 0) {
            DerValue derValue2 = data.getDerValue();
            if (derValue2.isContextSpecific((byte)0) && !derValue2.isConstructed()) {
                if (this.require != -1) {
                    throw new IOException("Duplicate requireExplicitPolicyfound in the PolicyConstraintsExtension");
                }
                derValue2.resetTag((byte)2);
                this.require = derValue2.getInteger();
            }
            else if (derValue2.isContextSpecific((byte)1) && !derValue2.isConstructed()) {
                if (this.inhibit != -1) {
                    throw new IOException("Duplicate inhibitPolicyMappingfound in the PolicyConstraintsExtension");
                }
                derValue2.resetTag((byte)2);
                this.inhibit = derValue2.getInteger();
            }
            else {
                throw new IOException("Invalid encoding of PolicyConstraint");
            }
        }
        return;
    }
    
    @Override
    public String toString() {
        String string = super.toString() + "PolicyConstraints: [  Require: ";
        String str;
        if (this.require == -1) {
            str = string + "unspecified;";
        }
        else {
            str = string + this.require + ";";
        }
        String string2 = str + "\tInhibit: ";
        String str2;
        if (this.inhibit == -1) {
            str2 = string2 + "unspecified";
        }
        else {
            str2 = string2 + this.inhibit;
        }
        return str2 + " ]\n";
    }
    
    @Override
    public void encode(OutputStream outputStream) throws IOException {
        DerOutputStream derOutputStream = new DerOutputStream();
        if (this.extensionValue == null) {
            this.extensionId = PKIXExtensions.PolicyConstraints_Id;
            this.critical = false;
            this.encodeThis();
        }
        super.encode(derOutputStream);
        outputStream.write(derOutputStream.toByteArray());
    }
    
    @Override
    public void set(String str, Object o) throws IOException {
        if (!(o instanceof Integer)) {
            throw new IOException("Attribute value should be of type Integer.");
        }
        if (str.equalsIgnoreCase("require")) {
            this.require = (int)o;
        }
        else if (str.equalsIgnoreCase("inhibit")) {
            this.inhibit = (int)o;
        }
        else {
            throw new IOException("Attribute name [" + str + "] not recognized by CertAttrSet:PolicyConstraints.");
        }
        this.encodeThis();
        return;
    }
    
    @Override
    public Integer get(String s) throws IOException {
        if (s.equalsIgnoreCase("require")) {
            return new Integer(this.require);
        }
        if (s.equalsIgnoreCase("inhibit")) {
            return new Integer(this.inhibit);
        }
        throw new IOException("Attribute name not recognized by CertAttrSet:PolicyConstraints.");
    }
    
    @Override
    public void delete(String s) throws IOException {
        if (s.equalsIgnoreCase("require")) {
            this.require = -1;
        }
        else if (s.equalsIgnoreCase("inhibit")) {
            this.inhibit = -1;
        }
        else {
            throw new IOException("Attribute name not recognized by CertAttrSet:PolicyConstraints.");
        }
        this.encodeThis();
    }
    
    @Override
    public Enumeration<String> getElements() {
        AttributeNameEnumeration attributeNameEnumeration = new AttributeNameEnumeration();
        attributeNameEnumeration.addElement("require");
        attributeNameEnumeration.addElement("inhibit");
        return attributeNameEnumeration.elements();
    }
    
    @Override
    public String getName() {
        return "PolicyConstraints";
    }
}
